<?php

class UserAlertUIController extends EntityDefaultUIController {

  /**
   * Overrides hook_menu() defaults.
   */
  public function hook_menu() {
    $id_count = count(explode('/', $this->path));
    $wildcard = isset($this->entityInfo['admin ui']['menu wildcard']) ? $this->entityInfo['admin ui']['menu wildcard'] : '%entity_object';
    $plural_label = isset($this->entityInfo['plural label']) ? $this->entityInfo['plural label'] : $this->entityInfo['label'] . 'ies';

    $items[$this->path] = array(
      'title' => $plural_label,
      'page callback' => 'drupal_get_form',
      'page arguments' => array('user_alert_admin'),
      'description' => 'Manage the User Alert entity for ' . variable_get('site_name', ''),
      'access arguments' => array('access administration pages'),
      'type' => MENU_LOCAL_TASK | MENU_NORMAL_ITEM,
      'file' => 'user_alert.admin.inc',
      'file path' => drupal_get_path('module', $this->entityInfo['module']) . '/includes',
    );

    $items[$this->path . '/add'] = array(
      'title' => 'Add a User Alert Message',
      'page callback' => 'user_alert_form_wrapper',
      'page arguments' => array('add', user_alert_create()),
      'access arguments' => array('create'),
      'file' => 'user_alert.admin.inc',
      'file path' => drupal_get_path('module', $this->entityInfo['module']) . '/includes',
      'type' => MENU_NORMAL_ITEM | MENU_LOCAL_ACTION,
    );

    $items['user_alert/add'] = array(
      'title' => 'Add a User Alert Message',
      'page callback' => 'user_alert_form_wrapper',
      'page arguments' => array('add', user_alert_create()),
      'access arguments' => array('create'),
      'file' => 'user_alert.admin.inc',
      'file path' => drupal_get_path('module', $this->entityInfo['module']) . '/includes',
      'type' => MENU_NORMAL_ITEM,
    );

    $items['user_alert/' . $wildcard] = array(
      'title callback' => 'user_alert_page_title',
      'title arguments' => array(1),
      'page callback' => 'user_alert_page_view',
      'page arguments' => array(1),
      'access callback' => 'user_alert_access',
      'access arguments' => array('view'),
      'type' => MENU_CALLBACK,
      'file' => 'user_alert.admin.inc',
      'file path' => drupal_get_path('module', $this->entityInfo['module']) . '/includes'
    );

    $items['user_alert/' . $wildcard . '/view'] = array(
      'title' => 'View',
      'type' => MENU_DEFAULT_LOCAL_TASK,
      'weight' => -10,
    );

    $items['user_alert/' . $wildcard . '/edit'] = array(
      'title' => t('Edit'),
      'page callback' => 'user_alert_form_wrapper',
      'page arguments' => array('edit', 1),
      'access callback' => 'user_alert_access',
      'access arguments' => array('edit'),
      'weight' => 0,
      'type' => MENU_LOCAL_TASK,
      'context' => MENU_CONTEXT_PAGE | MENU_CONTEXT_INLINE,
      'file' => 'user_alert.admin.inc',
      'file path' => drupal_get_path('module', $this->entityInfo['module']) . '/includes'
    );

    $items['user_alert/' . $wildcard . '/delete'] = array(
      'title' => t('Delete'),
      'page callback' => 'user_alert_form_wrapper',
      'page arguments' => array('delete', 1),
      'access callback' => 'user_alert_access',
      'access arguments' => array('delete'),
      'type' => MENU_LOCAL_TASK,
      'context' => MENU_CONTEXT_PAGE | MENU_CONTEXT_INLINE,
      'weight' => 100,
      'file' => 'user_alert.admin.inc',
      'file path' => drupal_get_path('module', $this->entityInfo['module']) . '/includes'
    );

    return $items;
  }
}

/**
 * Utility function to get the User Alert edit form.
 *
 * @param $op
 *   The operation the form should perform.
 * @param $user_alert
 *  The listing to perform the operation on.
 * @return array
 */

function user_alert_form_wrapper($op, $user_alert) {
  if ($op == 'create' || $op == 'add') {
    drupal_set_title(t('<em>@op</em> User Alert', array('@op' => ucwords($op))), PASS_THROUGH);
  } else {
    drupal_set_title(t('<em>@op</em> User Alert @id', array('@op' => ucwords($op), '@id' => $user_alert->user_alert_id)), PASS_THROUGH);
  }
  if ($op != 'delete') {
    return drupal_get_form('user_alert_edit_form', $op, $user_alert);
  } else {
    return drupal_get_form('user_alert_delete_form', $user_alert);
  }
}

/**
 * Wrapper function to create a User Alert entity
 * @param array $values
 * @return mixed
 */

function user_alert_create($values = array()) {
  return entity_get_controller('user_alert')->create($values);
}

/**
 * Edit form callback
 *
 * @param $form
 * @param $form_state
 * @param $op
 * @param $user_alert
 * @return array
 */

function user_alert_edit_form($form, &$form_state, $op, $user_alert) {
  $form_state['user_alert'] = $user_alert;

  field_attach_form('user_alert', $user_alert, $form, $form_state);

  $submit = array();

  if (!empty($form['#submit'])) {
    $submit += $form['#submit'];
  }

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save User Alert'),
    '#submit' => $submit + array('user_alert_edit_form_submit'),
    '#weight' => 1000,
  );

  return $form;
}

/**
 * Edit form submit callback
 *
 * @param $form
 * @param $form_state
 */

function user_alert_edit_form_submit($form, &$form_state) {
  $user_alert = $form_state['user_alert'];

  field_attach_submit('user_alert', $user_alert, $form, $form_state);

  $user_alert->save();
  drupal_set_message(t('User Alert @id has been updated.', array('@id' => $user_alert->user_alert_id)));
  $form_state['redirect'] = $user_alert->path();
}

/**
 * Delete confirmation form
 *
 * @param $form
 * @param $form_state
 * @param $user_alert
 * @return array
 */

function user_alert_delete_form($form, &$form_state, $user_alert) {
  $form['#user_alert'] = $user_alert;
  $form_state += array('user_alert' => $user_alert);

  return confirm_form($form,
    t('Are you sure you want to delete User Alert #%id?', array('%id' => $user_alert->user_alert_id)),
      'user_alert/' . $user_alert->user_alert_id,
    t('This action cannot be undone.'),
    t('Delete'),
    t('Cancel')
  );
}

/**
 * Delete form submit callback
 * @param $form
 * @param $form_state
 */

function user_alert_delete_form_submit($form, &$form_state) {
  $user_alert = $form_state['user_alert'];
  $user_alert->delete();
  drupal_set_message(t('Deleted User Alert #%id.', array('%id' => $user_alert->user_alert_id)));
  $form_state['redirect'] = 'admin';
}

/**
 * User Alert view page.
 */

function user_alert_page_view($entity, $view_mode = 'full', $langcode = NULL, $page = NULL) {
  $controller = entity_get_controller('user_alert');
  $content = $controller->view(array($entity->user_alert_id => $entity), $view_mode, $langcode, $page);

  return $content;
}

/**
 * Page callback, generates the overview page.
 * @return string
 */

function user_alert_admin($form, &$form_state) {
  $output = '<h3>User Alert Entity Admin</h3>';
  $output .= '<p>Below are all of the User Alert entities in the system.</p>';

  $form['header'] = array(
    '#type' => 'item',
    '#markup' => $output,
  );

  $header = array(
    'user_alert_id' => array('data' => t('User Alert ID'), 'field' => 'user_alert_id'),
    'name' => array('data' => t('Name'), 'field' => 'name'),
    'created' => array('data' => t('Created'), 'field' => 'created'),
    'operations' => array('data' => t('Operations')),
  );

  $query = db_select('user_alert', 'v')->extend('PagerDefault')->extend('TableSort');
  $result = $query
      ->fields('v', array('user_alert_id'))
      ->limit(15)
      ->orderByHeader($header)
      ->execute();

  $user_alert_ids = array();

  foreach ($result as $row) {
    $user_alert_ids[] = $row->user_alert_id;
  }

  $user_alerts = entity_load('user_alert', $user_alert_ids);

  $options = array();

  foreach ($user_alerts as $user_alert) {
    $links = menu_contextual_links('user_alert', 'user_alert', array($user_alert->user_alert_id));

    $options[$user_alert->user_alert_id] = array(
      'user_alert_id' => $user_alert->user_alert_id,
      'name' => l($user_alert->label, 'user_alert/' . $user_alert->user_alert_id),
      'created' => date('F j, Y', $user_alert->created),
      'operations' => theme('links', array('links' => $links, 'attributes' => array('class' => array('links', 'inline', 'operations')))),
    );
  }

  $form['user_alerts'] = array(
    '#type' => 'tableselect',
    '#header' => $header,
    '#options' => $options,
    '#empty' => t('No user alerts exist yet.'),
  );

  $form['pager'] = array('#theme' => 'pager');
  return $form;
}